@@ -424,16 +424,6 @@ class ContractingMLP(BaseNet):
     def forward(self, X):
         return self.model.forward(X)
 
-    def help(self) -> None :
-        whoami = "Contracting Multi-Layer Perceptron. The number of hidden units contracts by the contraction ratio.\n\n"
-        helptext = "Parameters ------------------------------------------------------------------------------------------------------- \n"
-        helptext += "dims:\t Dimension of the data. Normally X.shape[1].\n"
-        helptext += "n_classes:\t Number of classes in the classification task. If it is binary classification, n_classes=2\n"
-        helptext += "In defining hyperparameters and optimizer_type, we recommend you to define a dictionary.\n"
-        helptext += "Define a dictionary containing :\n\t-'optimizer_type': str (default='adam')\n\t-'contraction_ratio' : 0 < float <1 (default=0.5) \n\t-'dropout_p' : 0 <= float < 1 (default=0)\n\t-'weight_decay' : 0<= float < 1(default=0)\n\t-'lr' : float(default=1e-4)."
-        
-        text= whoami + helptext
-        print(text)
 ########################################################## _ContractingMLP & ContractingMLP (Ends) ##########################################################
 
 ########################################################## _CustomMLP & CustomMLP (Begins) ##########################################################
