@@ -717,13 +717,13 @@ class Project(BaseProject):
         wedges, texts, autotexts = plt.pie(sizes, autopct='%1.1f%%',textprops=dict(color="w"))
         if not plt_title:
             plt_title = 'Frequencies of'
-        plt.title('{} Model Structures'.format(plt_title))
+        plt.title('{} the Best Model Structures'.format(plt_title))
         plt.legend(wedges, best_model_structures.keys(), title="Model Structures", loc="center left",bbox_to_anchor=(1, 0, 0.5, 1))
         plt.setp(autotexts, size=8, weight="bold")
         plt.axis('equal')
         plt.show()
-        plt.savefig(self.project_path+"/results/{} Model Structures.png".format(plt_title))
-        self.project_logger.add_figure("results/{} Model Structures".format(plt_title), fig2)
+        plt.savefig(self.project_path+"/results/{} the Best Model Structures.png".format(plt_title))
+        self.project_logger.add_figure("results/{} the Best Model Structures".format(plt_title), fig2)
         plt.close(fig2)
         
         fig3 = plt.figure()
@@ -731,11 +731,11 @@ class Project(BaseProject):
         wedges, texts, autotexts = plt.pie(sizes,  autopct='%1.1f%%') 
         plt.axis('equal')
         plt.setp(autotexts, size=8, weight="bold")
-        plt.title('{} Model Types'.format(plt_title))
+        plt.title('{} the Best Model Types'.format(plt_title))
         plt.legend(wedges, best_model_types.keys(), title="Model Types", loc="center left",bbox_to_anchor=(1, 0, 0.5, 1))
         plt.show()
-        plt.savefig(self.project_path+"/results/{} Model Types.png".format(plt_title))
-        self.project_logger.add_figure("results/{} Model Types".format(plt_title), fig3)
+        plt.savefig(self.project_path+"/results/{} the Best Model Types.png".format(plt_title))
+        self.project_logger.add_figure("results/{} the Best Model Types".format(plt_title), fig3)
         plt.close(fig3)
 
         self.update_project_metadata()
@@ -769,7 +769,7 @@ class Project(BaseProject):
         plt.grid(True)
         plt.ylim = (ymin, ymax)
         if not plt_title:
-            plt_title = 'Best Performances-Model Type \n{}'.format(model_type.__name__)
+            plt_title = 'Best Performances : Model Type \n{}'.format(model_type.__name__)
         plt.title(plt_title)
         plt.show()
         plt.savefig(self.project_path+"/results/{}.png".format(plt_title))
@@ -808,11 +808,11 @@ class Project(BaseProject):
         plt.ylim = (ymin, ymax)
         
         if not plt_title:
-            plt_title = 'Best Performances'
+            plt_title = 'Performances of a Model Structure'
         plt.title(plt_title)
-        plt.savefig(self.project_path+"/results/{}.png".format(plt_title))
+        plt.savefig(self.project_path+"/results/{}.png".format(metadata))
         plt.show()
-        self.project_logger.add_figure('results/{}'.format(plt_title), fig1)
+        self.project_logger.add_figure('results/{}'.format(metadata), fig1)
         plt.close(fig1)
 
         self.update_project_metadata()
@@ -834,7 +834,7 @@ class Project(BaseProject):
     def plot_all_models(
         self,
         val_metric : str = "val/acc",
-        plt_title : str = "All Models"
+        plt_title : Optional[str] = None
     ):
 
         # find all available model structures
@@ -857,6 +857,8 @@ class Project(BaseProject):
         ymin_list, ymax_list = np.array(ymin_list), np.array(ymax_list)
         ymin, ymax = ymin_list.min(), ymax_list.max()
         
+        if not plt_title:
+            plt_title = "Performances Among Models"
         plt.title(plt_title)
         x = np.arange(len(random_number_list))
         plt.xticks(x, random_number_list)
